@@ -10,8 +10,7 @@ from .helpers import runSubprocess
 class Fpm:
   """ Class to handle fpm invocations """
   def __init__(self):
-    self.architecture = "x86_64"
-    self.buildDir = os.path.join(config.ali_prefix, 'sw/slc7_x86-64')
+    self.buildDir = os.path.join(config.ali_prefix, 'sw', config.architecture)
     self.forceBuild = ['--force'] if config.force_build else []
     self.packagePrefix = "o2-"
     self.targetDir = config.target_rpm_dir
@@ -25,23 +24,24 @@ class Fpm:
     if not os.path.exists(self.targetDir):
       os.makedirs(self.targetDir)
 
-    self.runtimeDepsDict = parseYamlDict(os.path.join(config.work_dir, 'runtime.el7.yaml'))
-    # self.develDepsDict = parseYamlDict("devel.el7.yaml") #placeholder
+    arch_split = config.architecture.split('_')
+    self.architecture = arch_split[1].replace('-', '_')
+    self.release_suffix = arch_split[0]
+
+    self.runtimeDepsDict = parseYamlDict(os.path.join(config.work_dir, 'runtime.' + self.release_suffix + '.yaml'))
 
   def run(self, name, version, deps, extra_deps, RPMS_GENERATED):
     """ Prepares arguments and executes fpm """
     fullVersion = version
     # split version and revision
-    split = version.split('-')
+    version_split = version.split('-')
     # split in case of vX.Y.Z-R
     # don't split if e.g. latest-o2-dataflow
-    if len(split) == 2:
-      version = split[0]
-      revision = split[1]
-      # prep iteration arg for fpm
-      iterationArg = ['--iteration', revision]
+    if len(version_split) == 2:
+      version = version_split[0]
+      iterationArg = ['--iteration', version_split[1] + '.' + self.release_suffix]
     else:
-      iterationArg = []
+      iterationArg = ['--iteration', self.release_suffix]
 
     # prep dir arguments
     # `=.` is necessary so that the complete source dir path
