@@ -10,7 +10,7 @@ class Module:
 
     def __init__(self, name):
         self.name = name
-        os.environ["MODULEPATH"] = os.path.join(config.ali_prefix, 'sw/MODULES/slc7_x86-64')
+        os.environ["MODULEPATH"] = os.path.join(config.ali_prefix, 'sw/MODULES', config.architecture)
         if not runSubprocess(['module', '--version', '--no-pager'], forceTty=True, shell=True):
             logging.critical('modules not found, exiting...')
             sys.exit(1)
